Class: EffectiveQbSyncMailerPreview

Inherits:
ActionMailer::Preview
  • Object
show all
Defined in:
lib/generators/templates/effective_qb_sync_mailer_preview.rb

Overview

In Rails 4.1 and above, visit: http://localhost:3000/rails/mailers to see a preview of the following emails:

Instance Method Summary collapse

Instance Method Details

#error_element_already_in_use ⇒ Object



17
18
19
# File 'lib/generators/templates/effective_qb_sync_mailer_preview.rb', line 17

def error_element_already_in_use
  order_error('The name "Peter Pan" of the list element is already in use.')
end

#error_invalid_reference_to_item ⇒ Object



13
14
15
# File 'lib/generators/templates/effective_qb_sync_mailer_preview.rb', line 13

def error_invalid_reference_to_item
  order_error('There is an invalid reference to QuickBooks Item "Tax On Sale" in the SalesReceipt line.')
end

#error_record_does_not_exist ⇒ Object

All order_errors are called from QbTicket.error! There are 3 general types of errors that occur



9
10
11
# File 'lib/generators/templates/effective_qb_sync_mailer_preview.rb', line 9

def error_record_does_not_exist
  order_error('Invalid argument. The specified record does not exist in the list.')
end

#error_unknown ⇒ Object



21
22
23
# File 'lib/generators/templates/effective_qb_sync_mailer_preview.rb', line 21

def error_unknown
  order_error('unknown')
end